Class: Hash
Instance Method Summary collapse
- #__object_type ⇒ Object
-
#__object_type=(ot) ⇒ Object
allows a Hash to be used in place of an ASObj …
Instance Method Details
#__object_type ⇒ Object
48 49 50 |
# File 'lib/wfjrd/wfjrd.rb', line 48 def __object_type @object_type end |
#__object_type=(ot) ⇒ Object
allows a Hash to be used in place of an ASObj … we don’t necessarily want a mixin on this, so just set a property
44 45 46 |
# File 'lib/wfjrd/wfjrd.rb', line 44 def __object_type= ot @object_type = ot end |